==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GridDataCommittedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceAggregatedResultDescriptionMetadata } from "./DataSourceAggregatedResultDescriptionMetadata";
import { GridDataCommittedEventArgsDescription } from "./GridDataCommittedEventArgsDescription";
/**
 * @hidden
 */
export let GridDataCommittedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridDataCommittedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridDataCommittedEventArgsDescriptionMetadata.a == null) {
                GridDataCommittedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridDataCommittedEventArgsDescriptionMetadata.c(GridDataCommittedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridDataCommittedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridDataCommittedEventArgsDescriptionMetadata.a);
            DataSourceAggregatedResultDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("CommitID", "Number:int");
            a.item("Changes", "Array:DataSourceAggregatedResultDescription:DataSourceAggregatedResult");
        }
        static d(a) {
            GridDataCommittedEventArgsDescriptionMetadata.b(a);
            a.ad("GridDataCommittedEventArgs", () => new GridDataCommittedEventArgsDescription());
            a.ac("GridDataCommittedEventArgs", GridDataCommittedEventArgsDescriptionMetadata.a);
        }
    }
    GridDataCommittedEventArgsDescriptionMetadata.$t = markType(GridDataCommittedEventArgsDescriptionMetadata, 'GridDataCommittedEventArgsDescriptionMetadata');
    GridDataCommittedEventArgsDescriptionMetadata.a = null;
    return GridDataCommittedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GridDataCommittedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceAggregatedResultDescriptionMetadata } from "./DataSourceAggregatedResultDescriptionMetadata";
import { GridDataCommittedEventArgsDescription } from "./GridDataCommittedEventArgsDescription";
/**
 * @hidden
 */
export let GridDataCommittedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridDataCommittedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridDataCommittedEventArgsDescriptionMetadata.a == null) {
                GridDataCommittedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridDataCommittedEventArgsDescriptionMetadata.c(GridDataCommittedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridDataCommittedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridDataCommittedEventArgsDescriptionMetadata.a);
            DataSourceAggregatedResultDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("CommitID", "Number:int");
            a.item("Changes", "Array:DataSourceAggregatedResultDescription:DataSourceAggregatedResult");
        }
        static d(a) {
            GridDataCommittedEventArgsDescriptionMetadata.b(a);
            a.ae("GridDataCommittedEventArgs", () => new GridDataCommittedEventArgsDescription());
            a.ad("GridDataCommittedEventArgs", GridDataCommittedEventArgsDescriptionMetadata.a);
        }
    }
    GridDataCommittedEventArgsDescriptionMetadata.$t = markType(GridDataCommittedEventArgsDescriptionMetadata, 'GridDataCommittedEventArgsDescriptionMetadata');
    GridDataCommittedEventArgsDescriptionMetadata.a = null;
    return GridDataCommittedEventArgsDescriptionMetadata;
})();
